package de.hawhamburg.reachability.json;

import java.util.Map;

import de.hawhamburg.lifecycle.data.JsonLPObject;
import de.hawhamburg.reachability.reasoner.enumeration.ReasonerDimension;

/**
 * Format of the JSON message used to transport the common sensor data from the sensor agents to the reasoner agent.
 * <br><br>
 * 
 * This class represents the structure of the JSON messages which describes the common internal data format. This 
 * messages will be sent from the sensor agents to the reasoner agent. This message is designed to transport the 
 * generalized form of sensor data and is obligate for each sensor agent.
 * 
 * @author  {@value de.hawhamburg.reachability.ProjectInfo#REACHABILITY_AGENT_AUTHOR} 
 * @version {@value de.hawhamburg.reachability.ProjectInfo#REACHABILITY_AGENT_VERSION}
 */
public class JsonReachabilitySensorData extends JsonLPObject {

    /**
     * The name of the sensor agent, which produces this data, as {@link String}.
     */
    public String Name;
    
    /**
     * The context dimension, for which this data is meant, as {@link ReasonerDimension}.
     */
    public ReasonerDimension Dimension;
    
    /**
     * The measured values as {@link Map} of {@link Integer} (index) to {@link Double} (value).
     */
    public Map<Integer, Double> Values;
    
    /**
     * The size of the value vector {@link #Values} as {@link Integer}.
     */
    public Integer Size;
    
    /**
     * The creation time of this data as UNIX timestamp.
     */
    public long CreationTime;
    
    /**
     * Public default constructor to create new instances of this class.
     */
    public JsonReachabilitySensorData() { }
}
